@@ -1,6 +1,6 @@
 package main
 
-import "github.com/jandedobbeleer/oh-my-posh/cli"
+import "github.com/jandedobbeleer/oh-my-posh/src/cli"
 
 var (
 	Version = "development"
