@@ -162,6 +162,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 		FolderSeparatorIcon string
 		GOOS                string
 		MaxDepth            int
+		MaxWidth            int
 		HideRootLocation    bool
 	}{
 		{
@@ -198,6 +199,34 @@ func TestAgnosterPathStyles(t *testing.T) {
 			FolderSeparatorIcon: " > ",
 		},
 
+		{
+			Style:               Powerlevel,
+			Expected:            "t > w > o > a > v > l > p > wh > we > i > wa > th > the > d > f > u > it > c > to > a > co > stream",
+			HomePath:            homeDir,
+			Pwd:                 "/there/was/once/a/very/long/path/which/wended/its/way/through/the/dark/forest/until/it/came/to/a/cold/stream",
+			PathSeparator:       "/",
+			FolderSeparatorIcon: " > ",
+			MaxWidth:            20,
+		},
+		{
+			Style:               Powerlevel,
+			Expected:            "t > w > o > a > v > l > p > which > wended > its > way > through > the",
+			HomePath:            homeDir,
+			Pwd:                 "/there/was/once/a/very/long/path/which/wended/its/way/through/the",
+			PathSeparator:       "/",
+			FolderSeparatorIcon: " > ",
+			MaxWidth:            70,
+		},
+		{
+			Style:               Powerlevel,
+			Expected:            "var/cache/pacman",
+			HomePath:            homeDir,
+			Pwd:                 "/var/cache/pacman",
+			PathSeparator:       "/",
+			FolderSeparatorIcon: "/",
+			MaxWidth:            50,
+		},
+
 		{
 			Style:               Letter,
 			Expected:            "~",
@@ -696,6 +725,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 				FolderSeparatorIcon: tc.FolderSeparatorIcon,
 				properties.Style:    tc.Style,
 				MaxDepth:            tc.MaxDepth,
+				MaxWidth:            tc.MaxWidth,
 				HideRootLocation:    tc.HideRootLocation,
 			},
 		}
